@@ -11,11 +11,11 @@ SVN::Look - A caching wrapper aroung the svnlook command.
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 =head1 SYNOPSIS
 
@@ -227,7 +227,7 @@ sub proplist {
 
 Returns a reference to a hash containing information about all file
 changes occurred in the revision. The hash always has the following
-pairs:
+keys:
 
 =over
 
@@ -249,8 +249,7 @@ A list of files that had properties modified in the revision.
 
 =item copied
 
-A hash mapping the old to the new name of each file moved in the
-revision.
+A hash containing information about each file or diretory copied in the revision. The hash keys are the names of elements copied to. The value associated with a key is a two-element array containing the name of the element copied from and the specific revision from which it was copied.
 
 =back
 
@@ -369,29 +368,29 @@ sub dirs_changed {
     return @{$self->{dirs_changed}};
 }
 
-=item B<copied_from>
-
-Returns the list of original names of files that were renamed in the
-revision/transaction.
-
-=cut
-
-sub copied_from {
-    my $self = shift;
-    return keys %{$self->changed_hash()->{copied_from}};
-}
-
 =item B<copied_to>
 
-Returns the list of new names of files that were renamed in the
-revision/transaction. The order of this list is guaranteed to agree
-with the order generated by the method copied_from.
+Returns the list of new names of files that were copied in the
+revision/transaction.
 
 =cut
 
 sub copied_to {
     my $self = shift;
-    return values %{$self->changed_hash()->{copied_from}};
+    return keys %{$self->changed_hash()->{copied}};
+}
+
+=item B<copied_from>
+
+Returns the list of original names of files that were copied in the
+revision/transaction. The order of this list is guaranteed to agree
+with the order generated by the method copied_to.
+
+=cut
+
+sub copied_from {
+    my $self = shift;
+    return map {$_->[0]} values %{$self->changed_hash()->{copied}};
 }
 
 =item B<cat> PATH
